#!/bin/bash
########################################################################################################################
# CCL-CCTF client for automatic API calls of all reference frequencies available meter and second "Mises en pratique" 
#                                                                                       Aurelie Harmegnies, 25/04/2023
#-----------------------------------------------------------------------------------------------------------------------
# Uses V1.0 of the API located at https://webtai.bipm.org/api/ccl-cctf/v1.0/xml_auto.html
#-----------------------------------------------------------------------------------------------------------------------
# Default parameters of request :
#  "date=" is current day ( variable dat)
#  "outdir" is the output directory ( default location ./xmls/ )
########################################################################################################################

# Variables
outdir='xmls'         # Output folder
dat=$(date +%F)     # current date, replace by other "YYYY-MM-DD", if necessary
#dat='2021-02-01'


# Script 
if [ -d $outdir ]; then
 rm -r $outdir
fi

echo "--- Get list of existing Reference Frequencies in MeP ---"
curl -s -k --url 'https://webtai.bipm.org/api/ccl-cctf/v1.0/xml_auto.html?target=list&date=${dat}' | xmlstarlet sel -T -t -m /list/element -v target -o '|' -v freqlabel -nl | sort > list.txt
sed s/\+\|/\%2B\|/ list.txt > list_url.txt
mkdir $outdir
for par in $(cat list_url.txt); do echo target=${par} ; curl -s -k --url "https://webtai.bipm.org/api/ccl-cctf/v1.0/xml_auto.html?target=${par}&date=${dat}" > ${outdir}/$(echo $par | tr -s '|' '_' | tr -d '+' ).xml ; done
for fich in $(ls ${outdir}/*%2B*) ; do rename 's/%2B/\+/' $fich ; done
echo 
echo 
echo "--- Generated XML files ---"
ls -1 $outdir/*
